summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorJustin McPherson <justin.mcpherson@nokia.com>2010-02-19 07:05:50 (GMT)
committerJustin McPherson <justin.mcpherson@nokia.com>2010-02-19 07:05:50 (GMT)
commit723d412d2b3fcb2f64594ff75ad94d469285aeb1 (patch)
tree2bf811bfbd59be616599a9d10a2aa7db60e05c01
parent6fa813a4d5b46523940f6af8ed74e6855bad49c9 (diff)
downloadQt-723d412d2b3fcb2f64594ff75ad94d469285aeb1.zip
Qt-723d412d2b3fcb2f64594ff75ad94d469285aeb1.tar.gz
Qt-723d412d2b3fcb2f64594ff75ad94d469285aeb1.tar.bz2
Complete namespace move; QtMedia -> QtMultimedia
-rw-r--r--src/multimedia/base/qmediaserviceprovider.cpp2
-rw-r--r--src/multimedia/base/qmetadatacontrol.cpp6
-rw-r--r--src/multimedia/qml/qmetadatacontrolmetaobject.cpp2
-rw-r--r--src/multimedia/qml/qmlgraphicsvideo.cpp142
-rw-r--r--src/plugins/mediaservices/directshow/mediaplayer/directshowmetadatacontrol.cpp18
-rw-r--r--src/plugins/mediaservices/gstreamer/mediaplayer/qgstreamermetadataprovider.cpp56
-rw-r--r--src/plugins/mediaservices/gstreamer/mediaplayer/qgstreamerplayersession.cpp8
-rw-r--r--tests/auto/qmediaobject/tst_qmediaobject.cpp38
-rw-r--r--tests/auto/qmediaserviceprovider/tst_qmediaserviceprovider.cpp32
-rw-r--r--tests/auto/qmlaudio/tst_qmlaudio.cpp22
-rw-r--r--tests/auto/qmlgraphicsvideo/tst_qmlgraphicsvideo.cpp2
11 files changed, 164 insertions, 164 deletions
diff --git a/src/multimedia/base/qmediaserviceprovider.cpp b/src/multimedia/base/qmediaserviceprovider.cpp
index fcf06d3..8d1e0fa 100644
--- a/src/multimedia/base/qmediaserviceprovider.cpp
+++ b/src/multimedia/base/qmediaserviceprovider.cpp
@@ -509,7 +509,7 @@ Q_GLOBAL_STATIC(QPluginServiceProvider, pluginProvider);
*/
/*!
- \fn QtMedia::SupportEstimate QMediaServiceProvider::hasSupport(const QByteArray &serviceType, const QString &mimeType, const QStringList& codecs, int flags) const
+ \fn QtMultimedia::SupportEstimate QMediaServiceProvider::hasSupport(const QByteArray &serviceType, const QString &mimeType, const QStringList& codecs, int flags) const
Returns how confident a media service provider is that is can provide a \a serviceType
service that is able to play media of a specific \a mimeType that is encoded using the listed
diff --git a/src/multimedia/base/qmetadatacontrol.cpp b/src/multimedia/base/qmetadatacontrol.cpp
index e45bb0c..3ecbe8d 100644
--- a/src/multimedia/base/qmetadatacontrol.cpp
+++ b/src/multimedia/base/qmetadatacontrol.cpp
@@ -58,7 +58,7 @@ QT_BEGIN_NAMESPACE
its current media it will implement QMetaDataControl. This control
provides functions for both retrieving and setting meta-data values.
Meta-data may be addressed by the well defined keys in the
- QtMedia::MetaData enumeration using the metaData() functions, or by
+ QtMultimedia::MetaData enumeration using the metaData() functions, or by
string keys using the extendedMetaData() functions.
The functionality provided by this control is exposed to application
@@ -117,13 +117,13 @@ QMetaDataControl::~QMetaDataControl()
*/
/*!
- \fn QVariant QMetaDataControl::metaData(QtMedia::MetaData key) const
+ \fn QVariant QMetaDataControl::metaData(QtMultimedia::MetaData key) const
Returns the meta-data for the given \a key.
*/
/*!
- \fn void QMetaDataControl::setMetaData(QtMedia::MetaData key, const QVariant &value)
+ \fn void QMetaDataControl::setMetaData(QtMultimedia::MetaData key, const QVariant &value)
Sets the \a value of the meta-data element with the given \a key.
*/
diff --git a/src/multimedia/qml/qmetadatacontrolmetaobject.cpp b/src/multimedia/qml/qmetadatacontrolmetaobject.cpp
index 7f9575e..47b6382 100644
--- a/src/multimedia/qml/qmetadatacontrolmetaobject.cpp
+++ b/src/multimedia/qml/qmetadatacontrolmetaobject.cpp
@@ -132,7 +132,7 @@ namespace
// Media
{ QtMultimedia::Size, "size" },
{ QtMultimedia::MediaType, "mediaType" },
-// { QtMedia::Duration, "duration" },
+// { QtMultimedia::Duration, "duration" },
// Audio
{ QtMultimedia::AudioBitRate, "audioBitRate" },
diff --git a/src/multimedia/qml/qmlgraphicsvideo.cpp b/src/multimedia/qml/qmlgraphicsvideo.cpp
index 1dd1f8b..fde505d 100644
--- a/src/multimedia/qml/qmlgraphicsvideo.cpp
+++ b/src/multimedia/qml/qmlgraphicsvideo.cpp
@@ -420,7 +420,7 @@ QT_END_NAMESPACE
This property holds the tile of the media.
- \sa {QtMedia::Title}
+ \sa {QtMultimedia::Title}
*/
/*!
@@ -428,7 +428,7 @@ QT_END_NAMESPACE
This property holds the sub-title of the media.
- \sa {QtMedia::SubTitle}
+ \sa {QtMultimedia::SubTitle}
*/
/*!
@@ -436,7 +436,7 @@ QT_END_NAMESPACE
This property holds the author of the media.
- \sa {QtMedia::Author}
+ \sa {QtMultimedia::Author}
*/
/*!
@@ -444,7 +444,7 @@ QT_END_NAMESPACE
This property holds a user comment about the media.
- \sa {QtMedia::Comment}
+ \sa {QtMultimedia::Comment}
*/
/*!
@@ -452,7 +452,7 @@ QT_END_NAMESPACE
This property holds a description of the media.
- \sa {QtMedia::Description}
+ \sa {QtMultimedia::Description}
*/
/*!
@@ -460,7 +460,7 @@ QT_END_NAMESPACE
This property holds the category of the media
- \sa {QtMedia::Category}
+ \sa {QtMultimedia::Category}
*/
/*!
@@ -468,7 +468,7 @@ QT_END_NAMESPACE
This property holds the genre of the media.
- \sa {QtMedia::Genre}
+ \sa {QtMultimedia::Genre}
*/
/*!
@@ -476,7 +476,7 @@ QT_END_NAMESPACE
This property holds the year of release of the media.
- \sa {QtMedia::Year}
+ \sa {QtMultimedia::Year}
*/
/*!
@@ -484,7 +484,7 @@ QT_END_NAMESPACE
This property holds the date of the media.
- \sa {QtMedia::Date}
+ \sa {QtMultimedia::Date}
*/
/*!
@@ -492,7 +492,7 @@ QT_END_NAMESPACE
This property holds a user rating of the media in the range of 0 to 100.
- \sa {QtMedia::UserRating}
+ \sa {QtMultimedia::UserRating}
*/
/*!
@@ -500,7 +500,7 @@ QT_END_NAMESPACE
This property holds a list of keywords describing the media.
- \sa {QtMedia::Keywords}
+ \sa {QtMultimedia::Keywords}
*/
/*!
@@ -508,7 +508,7 @@ QT_END_NAMESPACE
This property holds the language of the media, as an ISO 639-2 code.
- \sa {QtMedia::Language}
+ \sa {QtMultimedia::Language}
*/
/*!
@@ -516,7 +516,7 @@ QT_END_NAMESPACE
This property holds the publisher of the media.
- \sa {QtMedia::Publisher}
+ \sa {QtMultimedia::Publisher}
*/
/*!
@@ -524,7 +524,7 @@ QT_END_NAMESPACE
This property holds the media's copyright notice.
- \sa {QtMedia::Copyright}
+ \sa {QtMultimedia::Copyright}
*/
/*!
@@ -532,7 +532,7 @@ QT_END_NAMESPACE
This property holds the parental rating of the media.
- \sa {QtMedia::ParentalRating}
+ \sa {QtMultimedia::ParentalRating}
*/
/*!
@@ -541,7 +541,7 @@ QT_END_NAMESPACE
This property holds the name of the rating organisation responsible for the
parental rating of the media.
- \sa {QtMedia::RatingOrganisation}
+ \sa {QtMultimedia::RatingOrganisation}
*/
/*!
@@ -549,7 +549,7 @@ QT_END_NAMESPACE
This property property holds the size of the media in bytes.
- \sa {QtMedia::Size}
+ \sa {QtMultimedia::Size}
*/
/*!
@@ -557,7 +557,7 @@ QT_END_NAMESPACE
This property holds the type of the media.
- \sa {QtMedia::MediaType}
+ \sa {QtMultimedia::MediaType}
*/
/*!
@@ -566,7 +566,7 @@ QT_END_NAMESPACE
This property holds the bit rate of the media's audio stream ni bits per
second.
- \sa {QtMedia::AudioBitRate}
+ \sa {QtMultimedia::AudioBitRate}
*/
/*!
@@ -574,7 +574,7 @@ QT_END_NAMESPACE
This property holds the encoding of the media audio stream.
- \sa {QtMedia::AudioCodec}
+ \sa {QtMultimedia::AudioCodec}
*/
/*!
@@ -582,7 +582,7 @@ QT_END_NAMESPACE
This property holds the average volume level of the media.
- \sa {QtMedia::AverageLevel}
+ \sa {QtMultimedia::AverageLevel}
*/
/*!
@@ -590,7 +590,7 @@ QT_END_NAMESPACE
This property holds the number of channels in the media's audio stream.
- \sa {QtMedia::ChannelCount}
+ \sa {QtMultimedia::ChannelCount}
*/
/*!
@@ -598,7 +598,7 @@ QT_END_NAMESPACE
This property holds the peak volume of media's audio stream.
- \sa {QtMedia::PeakValue}
+ \sa {QtMultimedia::PeakValue}
*/
/*!
@@ -606,7 +606,7 @@ QT_END_NAMESPACE
This property holds the sample rate of the media's audio stream in hertz.
- \sa {QtMedia::SampleRate}
+ \sa {QtMultimedia::SampleRate}
*/
/*!
@@ -614,7 +614,7 @@ QT_END_NAMESPACE
This property holds the title of the album the media belongs to.
- \sa {QtMedia::AlbumTitle}
+ \sa {QtMultimedia::AlbumTitle}
*/
/*!
@@ -623,7 +623,7 @@ QT_END_NAMESPACE
This property holds the name of the principal artist of the album the media
belongs to.
- \sa {QtMedia::AlbumArtist}
+ \sa {QtMultimedia::AlbumArtist}
*/
/*!
@@ -631,7 +631,7 @@ QT_END_NAMESPACE
This property holds the names of artists contributing to the media.
- \sa {QtMedia::ContributingArtist}
+ \sa {QtMultimedia::ContributingArtist}
*/
/*!
@@ -639,7 +639,7 @@ QT_END_NAMESPACE
This property holds the composer of the media.
- \sa {QtMedia::Composer}
+ \sa {QtMultimedia::Composer}
*/
/*!
@@ -647,7 +647,7 @@ QT_END_NAMESPACE
This property holds the conductor of the media.
- \sa {QtMedia::Conductor}
+ \sa {QtMultimedia::Conductor}
*/
/*!
@@ -655,7 +655,7 @@ QT_END_NAMESPACE
This property holds the lyrics to the media.
- \sa {QtMedia::Lyrics}
+ \sa {QtMultimedia::Lyrics}
*/
/*!
@@ -663,7 +663,7 @@ QT_END_NAMESPACE
This property holds the mood of the media.
- \sa {QtMedia::Mood}
+ \sa {QtMultimedia::Mood}
*/
/*!
@@ -671,7 +671,7 @@ QT_END_NAMESPACE
This property holds the track number of the media.
- \sa {QtMedia::TrackNumber}
+ \sa {QtMultimedia::TrackNumber}
*/
/*!
@@ -679,7 +679,7 @@ QT_END_NAMESPACE
This property holds the number of track on the album containing the media.
- \sa {QtMedia::TrackNumber}
+ \sa {QtMultimedia::TrackNumber}
*/
/*!
@@ -687,7 +687,7 @@ QT_END_NAMESPACE
This property holds the URL of a small cover art image.
- \sa {QtMedia::CoverArtUrlSmall}
+ \sa {QtMultimedia::CoverArtUrlSmall}
*/
/*!
@@ -695,7 +695,7 @@ QT_END_NAMESPACE
This property holds the URL of a large cover art image.
- \sa {QtMedia::CoverArtUrlLarge}
+ \sa {QtMultimedia::CoverArtUrlLarge}
*/
/*!
@@ -703,7 +703,7 @@ QT_END_NAMESPACE
This property holds the dimension of an image or video.
- \sa {QtMedia::Resolution}
+ \sa {QtMultimedia::Resolution}
*/
/*!
@@ -711,7 +711,7 @@ QT_END_NAMESPACE
This property holds the pixel aspect ratio of an image or video.
- \sa {QtMedia::PixelAspectRatio}
+ \sa {QtMultimedia::PixelAspectRatio}
*/
/*!
@@ -719,7 +719,7 @@ QT_END_NAMESPACE
This property holds the frame rate of the media's video stream.
- \sa {QtMedia::VideoFrameRate}
+ \sa {QtMultimedia::VideoFrameRate}
*/
/*!
@@ -728,7 +728,7 @@ QT_END_NAMESPACE
This property holds the bit rate of the media's video stream in bits per
second.
- \sa {QtMedia::VideoBitRate}
+ \sa {QtMultimedia::VideoBitRate}
*/
/*!
@@ -736,7 +736,7 @@ QT_END_NAMESPACE
This property holds the encoding of the media's video stream.
- \sa {QtMedia::VideoCodec}
+ \sa {QtMultimedia::VideoCodec}
*/
/*!
@@ -744,7 +744,7 @@ QT_END_NAMESPACE
This property holds the URL of a poster image.
- \sa {QtMedia::PosterUrl}
+ \sa {QtMultimedia::PosterUrl}
*/
/*!
@@ -752,7 +752,7 @@ QT_END_NAMESPACE
This property holds the chapter number of the media.
- \sa {QtMedia::ChapterNumber}
+ \sa {QtMultimedia::ChapterNumber}
*/
/*!
@@ -760,7 +760,7 @@ QT_END_NAMESPACE
This property holds the director of the media.
- \sa {QtMedia::Director}
+ \sa {QtMultimedia::Director}
*/
/*!
@@ -768,7 +768,7 @@ QT_END_NAMESPACE
This property holds the lead performer in the media.
- \sa {QtMedia::LeadPerformer}
+ \sa {QtMultimedia::LeadPerformer}
*/
/*!
@@ -776,7 +776,7 @@ QT_END_NAMESPACE
This property holds the writer of the media.
- \sa {QtMedia::Writer}
+ \sa {QtMultimedia::Writer}
*/
// The remaining properties are related to photos, and are technically
@@ -786,157 +786,157 @@ QT_END_NAMESPACE
/*!
\qmlproperty variant Video::cameraManufacturer
- \sa {QtMedia::CameraManufacturer}
+ \sa {QtMultimedia::CameraManufacturer}
*/
/*!
\qmlproperty variant Video::cameraModel
- \sa {QtMedia::CameraModel}
+ \sa {QtMultimedia::CameraModel}
*/
/*!
\qmlproperty variant Video::event
- \sa {QtMedia::Event}
+ \sa {QtMultimedia::Event}
*/
/*!
\qmlproperty variant Video::subject
- \sa {QtMedia::Subject}
+ \sa {QtMultimedia::Subject}
*/
/*!
\qmlproperty variant Video::orientation
- \sa {QtMedia::Orientation}
+ \sa {QtMultimedia::Orientation}
*/
/*!
\qmlproperty variant Video::exposureTime
- \sa {QtMedia::ExposureTime}
+ \sa {QtMultimedia::ExposureTime}
*/
/*!
\qmlproperty variant Video::fNumber
- \sa {QtMedia::FNumber}
+ \sa {QtMultimedia::FNumber}
*/
/*!
\qmlproperty variant Video::exposureProgram
- \sa {QtMedia::ExposureProgram}
+ \sa {QtMultimedia::ExposureProgram}
*/
/*!
\qmlproperty variant Video::isoSpeedRatings
- \sa {QtMedia::ISOSpeedRatings}
+ \sa {QtMultimedia::ISOSpeedRatings}
*/
/*!
\qmlproperty variant Video::exposureBiasValue
- \sa {QtMedia::ExposureBiasValue}
+ \sa {QtMultimedia::ExposureBiasValue}
*/
/*!
\qmlproperty variant Video::dateTimeDigitized
- \sa {QtMedia::DateTimeDigitized}
+ \sa {QtMultimedia::DateTimeDigitized}
*/
/*!
\qmlproperty variant Video::subjectDistance
- \sa {QtMedia::SubjectDistance}
+ \sa {QtMultimedia::SubjectDistance}
*/
/*!
\qmlproperty variant Video::meteringMode
- \sa {QtMedia::MeteringMode}
+ \sa {QtMultimedia::MeteringMode}
*/
/*!
\qmlproperty variant Video::lightSource
- \sa {QtMedia::LightSource}
+ \sa {QtMultimedia::LightSource}
*/
/*!
\qmlproperty variant Video::flash
- \sa {QtMedia::Flash}
+ \sa {QtMultimedia::Flash}
*/
/*!
\qmlproperty variant Video::focalLength
- \sa {QtMedia::FocalLength}
+ \sa {QtMultimedia::FocalLength}
*/
/*!
\qmlproperty variant Video::exposureMode
- \sa {QtMedia::ExposureMode}
+ \sa {QtMultimedia::ExposureMode}
*/
/*!
\qmlproperty variant Video::whiteBalance
- \sa {QtMedia::WhiteBalance}
+ \sa {QtMultimedia::WhiteBalance}
*/
/*!
\qmlproperty variant Video::DigitalZoomRatio
- \sa {QtMedia::DigitalZoomRatio}
+ \sa {QtMultimedia::DigitalZoomRatio}
*/
/*!
\qmlproperty variant Video::focalLengthIn35mmFilm
- \sa {QtMedia::FocalLengthIn35mmFile}
+ \sa {QtMultimedia::FocalLengthIn35mmFile}
*/
/*!
\qmlproperty variant Video::sceneCaptureType
- \sa {QtMedia::SceneCaptureType}
+ \sa {QtMultimedia::SceneCaptureType}
*/
/*!
\qmlproperty variant Video::gainControl
- \sa {QtMedia::GainControl}
+ \sa {QtMultimedia::GainControl}
*/
/*!
\qmlproperty variant Video::contrast
- \sa {QtMedia::contrast}
+ \sa {QtMultimedia::contrast}
*/
/*!
\qmlproperty variant Video::saturation
- \sa {QtMedia::Saturation}
+ \sa {QtMultimedia::Saturation}
*/
/*!
\qmlproperty variant Video::sharpness
- \sa {QtMedia::Sharpness}
+ \sa {QtMultimedia::Sharpness}
*/
/*!
\qmlproperty variant Video::deviceSettingDescription
- \sa {QtMedia::DeviceSettingDescription}
+ \sa {QtMultimedia::DeviceSettingDescription}
*/
#endif
diff --git a/src/plugins/mediaservices/directshow/mediaplayer/directshowmetadatacontrol.cpp b/src/plugins/mediaservices/directshow/mediaplayer/directshowmetadatacontrol.cpp
index 56820d2..7b2552f 100644
--- a/src/plugins/mediaservices/directshow/mediaplayer/directshowmetadatacontrol.cpp
+++ b/src/plugins/mediaservices/directshow/mediaplayer/directshowmetadatacontrol.cpp
@@ -71,10 +71,10 @@ static const QWMMetaDataKeyLookup qt_wmMetaDataKeys[] =
{ QtMultimedia::Description, L"Description" },
{ QtMultimedia::Category, L"WM/Category" },
{ QtMultimedia::Genre, L"WM/Genre" },
- //{ QtMedia::Date, 0 },
+ //{ QtMultimedia::Date, 0 },
{ QtMultimedia::Year, L"WM/Year" },
{ QtMultimedia::UserRating, L"UserRating" },
- //{ QtMedia::MetaDatawords, 0 },
+ //{ QtMultimedia::MetaDatawords, 0 },
{ QtMultimedia::Language, L"Language" },
{ QtMultimedia::Publisher, L"WM/Publisher" },
{ QtMultimedia::Copyright, L"Copyright" },
@@ -101,20 +101,20 @@ static const QWMMetaDataKeyLookup qt_wmMetaDataKeys[] =
{ QtMultimedia::Lyrics, L"WM/Lyrics" },
{ QtMultimedia::Mood, L"WM/Mood" },
{ QtMultimedia::TrackNumber, L"WM/TrackNumber" },
- //{ QtMedia::TrackCount, 0 },
- //{ QtMedia::CoverArtUriSmall, 0 },
- //{ QtMedia::CoverArtUriLarge, 0 },
+ //{ QtMultimedia::TrackCount, 0 },
+ //{ QtMultimedia::CoverArtUriSmall, 0 },
+ //{ QtMultimedia::CoverArtUriLarge, 0 },
// Image/Video
- //{ QtMedia::Resolution, 0 },
- //{ QtMedia::PixelAspectRatio, 0 },
+ //{ QtMultimedia::Resolution, 0 },
+ //{ QtMultimedia::PixelAspectRatio, 0 },
// Video
- //{ QtMedia::FrameRate, 0 },
+ //{ QtMultimedia::FrameRate, 0 },
{ QtMultimedia::VideoBitRate, L"VideoBitRate" },
{ QtMultimedia::VideoCodec, L"VideoCodec" },
- //{ QtMedia::PosterUri, 0 },
+ //{ QtMultimedia::PosterUri, 0 },
// Movie
{ QtMultimedia::ChapterNumber, L"ChapterNumber" },
diff --git a/src/plugins/mediaservices/gstreamer/mediaplayer/qgstreamerplayersession.cpp b/src/plugins/mediaservices/gstreamer/mediaplayer/qgstreamerplayersession.cpp
index 6945c2a..2e5d10f 100644
--- a/src/plugins/mediaservices/gstreamer/mediaplayer/qgstreamerplayersession.cpp
+++ b/src/plugins/mediaservices/gstreamer/mediaplayer/qgstreamerplayersession.cpp
@@ -616,7 +616,7 @@ void QGstreamerPlayerSession::getStreamsInfo()
for (int i=0; i<m_streamTypes.count(); i++) {
QMediaStreamsControl::StreamType streamType = m_streamTypes[i];
- QMap<QtMedia::MetaData, QVariant> streamProperties;
+ QMap<QtMultimedia::MetaData, QVariant> streamProperties;
int streamIndex = i - m_playbin2StreamOffset[streamType];
@@ -638,7 +638,7 @@ void QGstreamerPlayerSession::getStreamsInfo()
if (tags && gst_is_tag_list(tags)) {
gchar *languageCode = 0;
if (gst_tag_list_get_string(tags, GST_TAG_LANGUAGE_CODE, &languageCode))
- streamProperties[QtMedia::Language] = QString::fromUtf8(languageCode);
+ streamProperties[QtMultimedia::Language] = QString::fromUtf8(languageCode);
//qDebug() << "language for setream" << i << QString::fromUtf8(languageCode);
g_free (languageCode);
@@ -691,8 +691,8 @@ void QGstreamerPlayerSession::getStreamsInfo()
// break;
// }
//
-// QMap<QtMedia::MetaData, QVariant> streamProperties;
-// streamProperties[QtMedia::Language] = QString::fromUtf8(languageCode);
+// QMap<QtMultimedia::MetaData, QVariant> streamProperties;
+// streamProperties[QtMultimedia::Language] = QString::fromUtf8(languageCode);
//
// m_streamProperties.append(streamProperties);
// m_streamTypes.append(streamType);
diff --git a/tests/auto/qmediaobject/tst_qmediaobject.cpp b/tests/auto/qmediaobject/tst_qmediaobject.cpp
index 1dbb2c1..2128b35 100644
--- a/tests/auto/qmediaobject/tst_qmediaobject.cpp
+++ b/tests/auto/qmediaobject/tst_qmediaobject.cpp
@@ -93,13 +93,13 @@ public:
if (m_available != available)
emit metaDataAvailableChanged(m_available = available);
}
- QList<QtMedia::MetaData> availableMetaData() const { return m_data.keys(); }
+ QList<QtMultimedia::MetaData> availableMetaData() const { return m_data.keys(); }
bool isWritable() const { return m_writable; }
void setWritable(bool writable) { emit writableChanged(m_writable = writable); }
- QVariant metaData(QtMedia::MetaData key) const { return m_data.value(key); }
- void setMetaData(QtMedia::MetaData key, const QVariant &value) {
+ QVariant metaData(QtMultimedia::MetaData key) const { return m_data.value(key); }
+ void setMetaData(QtMultimedia::MetaData key, const QVariant &value) {
m_data.insert(key, value); }
QVariant extendedMetaData(const QString &key) const { return m_extendedData.value(key); }
@@ -117,7 +117,7 @@ public:
bool m_available;
bool m_writable;
- QMap<QtMedia::MetaData, QVariant> m_data;
+ QMap<QtMultimedia::MetaData, QVariant> m_data;
QMap<QString, QVariant> m_extendedData;
};
@@ -376,12 +376,12 @@ void tst_QMediaObject::nullMetaDataControl()
QCOMPARE(object.isMetaDataAvailable(), false);
QCOMPARE(object.isMetaDataWritable(), false);
- object.setMetaData(QtMedia::Title, title);
+ object.setMetaData(QtMultimedia::Title, title);
object.setExtendedMetaData(titleKey, title);
- QCOMPARE(object.metaData(QtMedia::Title).toString(), QString());
+ QCOMPARE(object.metaData(QtMultimedia::Title).toString(), QString());
QCOMPARE(object.extendedMetaData(titleKey).toString(), QString());
- QCOMPARE(object.availableMetaData(), QList<QtMedia::MetaData>());
+ QCOMPARE(object.availableMetaData(), QList<QtMultimedia::MetaData>());
QCOMPARE(object.availableExtendedMetaData(), QStringList());
QCOMPARE(spy.count(), 0);
}
@@ -470,18 +470,18 @@ void tst_QMediaObject::metaData()
QtTestMediaObject object(&service);
QVERIFY(object.availableMetaData().isEmpty());
- service.metaData.m_data.insert(QtMedia::AlbumArtist, artist);
- service.metaData.m_data.insert(QtMedia::Title, title);
- service.metaData.m_data.insert(QtMedia::Genre, genre);
+ service.metaData.m_data.insert(QtMultimedia::AlbumArtist, artist);
+ service.metaData.m_data.insert(QtMultimedia::Title, title);
+ service.metaData.m_data.insert(QtMultimedia::Genre, genre);
- QCOMPARE(object.metaData(QtMedia::AlbumArtist).toString(), artist);
- QCOMPARE(object.metaData(QtMedia::Title).toString(), title);
+ QCOMPARE(object.metaData(QtMultimedia::AlbumArtist).toString(), artist);
+ QCOMPARE(object.metaData(QtMultimedia::Title).toString(), title);
- QList<QtMedia::MetaData> metaDataKeys = object.availableMetaData();
+ QList<QtMultimedia::MetaData> metaDataKeys = object.availableMetaData();
QCOMPARE(metaDataKeys.size(), 3);
- QVERIFY(metaDataKeys.contains(QtMedia::AlbumArtist));
- QVERIFY(metaDataKeys.contains(QtMedia::Title));
- QVERIFY(metaDataKeys.contains(QtMedia::Genre));
+ QVERIFY(metaDataKeys.contains(QtMultimedia::AlbumArtist));
+ QVERIFY(metaDataKeys.contains(QtMultimedia::Title));
+ QVERIFY(metaDataKeys.contains(QtMultimedia::Genre));
}
void tst_QMediaObject::setMetaData_data()
@@ -501,9 +501,9 @@ void tst_QMediaObject::setMetaData()
QtTestMediaObject object(&service);
- object.setMetaData(QtMedia::Title, title);
- QCOMPARE(object.metaData(QtMedia::Title).toString(), title);
- QCOMPARE(service.metaData.m_data.value(QtMedia::Title).toString(), title);
+ object.setMetaData(QtMultimedia::Title, title);
+ QCOMPARE(object.metaData(QtMultimedia::Title).toString(), title);
+ QCOMPARE(service.metaData.m_data.value(QtMultimedia::Title).toString(), title);
}
void tst_QMediaObject::extendedMetaData()
diff --git a/tests/auto/qmediaserviceprovider/tst_qmediaserviceprovider.cpp b/tests/auto/qmediaserviceprovider/tst_qmediaserviceprovider.cpp
index 9409394..9bca189 100644
--- a/tests/auto/qmediaserviceprovider/tst_qmediaserviceprovider.cpp
+++ b/tests/auto/qmediaserviceprovider/tst_qmediaserviceprovider.cpp
@@ -88,16 +88,16 @@ public:
delete service;
}
- QtMedia::SupportEstimate hasSupport(const QString &mimeType, const QStringList& codecs) const
+ QtMultimedia::SupportEstimate hasSupport(const QString &mimeType, const QStringList& codecs) const
{
if (codecs.contains(QLatin1String("mpeg4")))
- return QtMedia::NotSupported;
+ return QtMultimedia::NotSupported;
if (mimeType == "audio/ogg") {
- return QtMedia::ProbablySupported;
+ return QtMultimedia::ProbablySupported;
}
- return QtMedia::MaybeSupported;
+ return QtMultimedia::MaybeSupported;
}
QStringList supportedMimeTypes() const
@@ -147,14 +147,14 @@ public:
delete service;
}
- QtMedia::SupportEstimate hasSupport(const QString &mimeType, const QStringList& codecs) const
+ QtMultimedia::SupportEstimate hasSupport(const QString &mimeType, const QStringList& codecs) const
{
Q_UNUSED(codecs);
if (mimeType == "audio/wav")
- return QtMedia::PreferedService;
+ return QtMultimedia::PreferedService;
- return QtMedia::NotSupported;
+ return QtMultimedia::NotSupported;
}
QStringList supportedMimeTypes() const
@@ -282,7 +282,7 @@ void tst_QMediaServiceProvider::testHasSupport()
{
MockMediaServiceProvider mockProvider;
QCOMPARE(mockProvider.hasSupport(QByteArray(Q_MEDIASERVICE_MEDIAPLAYER), "video/ogv", QStringList()),
- QtMedia::MaybeSupported);
+ QtMultimedia::MaybeSupported);
QMediaServiceProvider *provider = QMediaServiceProvider::defaultServiceProvider();
@@ -290,27 +290,27 @@ void tst_QMediaServiceProvider::testHasSupport()
QSKIP("No default provider", SkipSingle);
QCOMPARE(provider->hasSupport(QByteArray(Q_MEDIASERVICE_MEDIAPLAYER), "video/ogv", QStringList()),
- QtMedia::MaybeSupported);
+ QtMultimedia::MaybeSupported);
QCOMPARE(provider->hasSupport(QByteArray(Q_MEDIASERVICE_MEDIAPLAYER), "audio/ogg", QStringList()),
- QtMedia::ProbablySupported);
+ QtMultimedia::ProbablySupported);
//while the service returns PreferredService, provider should return ProbablySupported
QCOMPARE(provider->hasSupport(QByteArray(Q_MEDIASERVICE_MEDIAPLAYER), "audio/wav", QStringList()),
- QtMedia::ProbablySupported);
+ QtMultimedia::ProbablySupported);
//even while all the plugins with "hasSupport" returned NotSupported,
//MockServicePlugin3 has no "hasSupport" interface, so MaybeSupported
QCOMPARE(provider->hasSupport(QByteArray(Q_MEDIASERVICE_MEDIAPLAYER), "video/avi",
QStringList() << "mpeg4"),
- QtMedia::MaybeSupported);
+ QtMultimedia::MaybeSupported);
QCOMPARE(provider->hasSupport(QByteArray("non existing service"), "video/ogv", QStringList()),
- QtMedia::NotSupported);
+ QtMultimedia::NotSupported);
- QCOMPARE(QMediaPlayer::hasSupport("video/ogv"), QtMedia::MaybeSupported);
- QCOMPARE(QMediaPlayer::hasSupport("audio/ogg"), QtMedia::ProbablySupported);
- QCOMPARE(QMediaPlayer::hasSupport("audio/wav"), QtMedia::ProbablySupported);
+ QCOMPARE(QMediaPlayer::hasSupport("video/ogv"), QtMultimedia::MaybeSupported);
+ QCOMPARE(QMediaPlayer::hasSupport("audio/ogg"), QtMultimedia::ProbablySupported);
+ QCOMPARE(QMediaPlayer::hasSupport("audio/wav"), QtMultimedia::ProbablySupported);
//ensure the correct media player plugin is choosen for mime type
QMediaPlayer simplePlayer(0, QMediaPlayer::LowLatency);
diff --git a/tests/auto/qmlaudio/tst_qmlaudio.cpp b/tests/auto/qmlaudio/tst_qmlaudio.cpp
index cb205ac..068317f 100644
--- a/tests/auto/qmlaudio/tst_qmlaudio.cpp
+++ b/tests/auto/qmlaudio/tst_qmlaudio.cpp
@@ -76,7 +76,7 @@ private slots:
void error();
};
-Q_DECLARE_METATYPE(QtMedia::MetaData);
+Q_DECLARE_METATYPE(QtMultimedia::MetaData);
Q_DECLARE_METATYPE(QmlAudio::Error);
class QtTestMediaPlayerControl : public QMediaPlayerControl
@@ -192,20 +192,20 @@ public:
bool isWritable() const { return true; }
bool isMetaDataAvailable() const { return true; }
- QVariant metaData(QtMedia::MetaData key) const { return m_metaData.value(key); }
- void setMetaData(QtMedia::MetaData key, const QVariant &value) {
+ QVariant metaData(QtMultimedia::MetaData key) const { return m_metaData.value(key); }
+ void setMetaData(QtMultimedia::MetaData key, const QVariant &value) {
m_metaData.insert(key, value); emit metaDataChanged(); }
- void setMetaData(const QMap<QtMedia::MetaData, QVariant> &metaData) {
+ void setMetaData(const QMap<QtMultimedia::MetaData, QVariant> &metaData) {
m_metaData = metaData; emit metaDataChanged(); }
- QList<QtMedia::MetaData> availableMetaData() const { return m_metaData.keys(); }
+ QList<QtMultimedia::MetaData> availableMetaData() const { return m_metaData.keys(); }
QVariant extendedMetaData(const QString &) const { return QVariant(); }
void setExtendedMetaData(const QString &, const QVariant &) {}
QStringList availableExtendedMetaData() const { return QStringList(); }
private:
- QMap<QtMedia::MetaData, QVariant> m_metaData;
+ QMap<QtMultimedia::MetaData, QVariant> m_metaData;
};
class QtTestMediaService : public QMediaService
@@ -1108,25 +1108,25 @@ void tst_QmlAudio::status()
void tst_QmlAudio::metaData_data()
{
QTest::addColumn<QByteArray>("propertyName");
- QTest::addColumn<QtMedia::MetaData>("propertyKey");
+ QTest::addColumn<QtMultimedia::MetaData>("propertyKey");
QTest::addColumn<QVariant>("value1");
QTest::addColumn<QVariant>("value2");
QTest::newRow("title")
<< QByteArray("title")
- << QtMedia::Title
+ << QtMultimedia::Title
<< QVariant(QString::fromLatin1("This is a title"))
<< QVariant(QString::fromLatin1("This is another title"));
QTest::newRow("genre")
<< QByteArray("genre")
- << QtMedia::Genre
+ << QtMultimedia::Genre
<< QVariant(QString::fromLatin1("rock"))
<< QVariant(QString::fromLatin1("pop"));
QTest::newRow("trackNumber")
<< QByteArray("trackNumber")
- << QtMedia::TrackNumber
+ << QtMultimedia::TrackNumber
<< QVariant(8)
<< QVariant(12);
}
@@ -1134,7 +1134,7 @@ void tst_QmlAudio::metaData_data()
void tst_QmlAudio::metaData()
{
QFETCH(QByteArray, propertyName);
- QFETCH(QtMedia::MetaData, propertyKey);
+ QFETCH(QtMultimedia::MetaData, propertyKey);
QFETCH(QVariant, value1);
QFETCH(QVariant, value2);
diff --git a/tests/auto/qmlgraphicsvideo/tst_qmlgraphicsvideo.cpp b/tests/auto/qmlgraphicsvideo/tst_qmlgraphicsvideo.cpp
index a09a6a2..0da094d 100644
--- a/tests/auto/qmlgraphicsvideo/tst_qmlgraphicsvideo.cpp
+++ b/tests/auto/qmlgraphicsvideo/tst_qmlgraphicsvideo.cpp
@@ -73,7 +73,7 @@ private slots:
void geometry();
};
-Q_DECLARE_METATYPE(QtMedia::MetaData);
+Q_DECLARE_METATYPE(QtMultimedia::MetaData);
Q_DECLARE_METATYPE(QmlGraphicsVideo::Error);
class QtTestMediaPlayerControl : public QMediaPlayerControl
diff --git a/src/plugins/mediaservices/gstreamer/mediaplayer/qgstreamermetadataprovider.cpp b/src/plugins/mediaservices/gstreamer/mediaplayer/qgstreamermetadataprovider.cpp
index 456dcfd..49eeb23 100644
--- a/src/plugins/mediaservices/gstreamer/mediaplayer/qgstreamermetadataprovider.cpp
+++ b/src/plugins/mediaservices/gstreamer/mediaplayer/qgstreamermetadataprovider.cpp
@@ -54,70 +54,70 @@ struct QGstreamerMetaDataKeyLookup
static const QGstreamerMetaDataKeyLookup qt_gstreamerMetaDataKeys[] =
{
{ QtMultimedia::Title, GST_TAG_TITLE },
- //{ QtMedia::SubTitle, 0 },
- //{ QtMedia::Author, 0 },
+ //{ QtMultimedia::SubTitle, 0 },
+ //{ QtMultimedia::Author, 0 },
{ QtMultimedia::Comment, GST_TAG_COMMENT },
{ QtMultimedia::Description, GST_TAG_DESCRIPTION },
- //{ QtMedia::Category, 0 },
+ //{ QtMultimedia::Category, 0 },
{ QtMultimedia::Genre, GST_TAG_GENRE },
{ QtMultimedia::Year, "year" },
- //{ QtMedia::UserRating, 0 },
+ //{ QtMultimedia::UserRating, 0 },
{ QtMultimedia::Language, GST_TAG_LANGUAGE_CODE },
{ QtMultimedia::Publisher, GST_TAG_ORGANIZATION },
{ QtMultimedia::Copyright, GST_TAG_COPYRIGHT },
- //{ QtMedia::ParentalRating, 0 },
- //{ QtMedia::RatingOrganisation, 0 },
+ //{ QtMultimedia::ParentalRating, 0 },
+ //{ QtMultimedia::RatingOrganisation, 0 },
// Media
- //{ QtMedia::Size, 0 },
- //{ QtMedia::MediaType, 0 },
+ //{ QtMultimedia::Size, 0 },
+ //{ QtMultimedia::MediaType, 0 },
{ QtMultimedia::Duration, GST_TAG_DURATION },
// Audio
{ QtMultimedia::AudioBitRate, GST_TAG_BITRATE },
{ QtMultimedia::AudioCodec, GST_TAG_AUDIO_CODEC },
- //{ QtMedia::ChannelCount, 0 },
- //{ QtMedia::Frequency, 0 },
+ //{ QtMultimedia::ChannelCount, 0 },
+ //{ QtMultimedia::Frequency, 0 },
// Music
{ QtMultimedia::AlbumTitle, GST_TAG_ALBUM },
{ QtMultimedia::AlbumArtist, GST_TAG_ARTIST},
{ QtMultimedia::ContributingArtist, GST_TAG_PERFORMER },
#if (GST_VERSION_MAJOR >= 0) && (GST_VERSION_MINOR >= 10) && (GST_VERSION_MICRO >= 19)
- { QtMedia::Composer, GST_TAG_COMPOSER },
+ { QtMultimedia::Composer, GST_TAG_COMPOSER },
#endif
//{ QtMedia::Conductor, 0 },
//{ QtMedia::Lyrics, 0 },
//{ QtMedia::Mood, 0 },
{ QtMultimedia::TrackNumber, GST_TAG_TRACK_NUMBER },
- //{ QtMedia::CoverArtUrlSmall, 0 },
- //{ QtMedia::CoverArtUrlLarge, 0 },
+ //{ QtMultimedia::CoverArtUrlSmall, 0 },
+ //{ QtMultimedia::CoverArtUrlLarge, 0 },
// Image/Video
- //{ QtMedia::Resolution, 0 },
- //{ QtMedia::PixelAspectRatio, 0 },
+ //{ QtMultimedia::Resolution, 0 },
+ //{ QtMultimedia::PixelAspectRatio, 0 },
// Video
- //{ QtMedia::VideoFrameRate, 0 },
- //{ QtMedia::VideoBitRate, 0 },
+ //{ QtMultimedia::VideoFrameRate, 0 },
+ //{ QtMultimedia::VideoBitRate, 0 },
{ QtMultimedia::VideoCodec, GST_TAG_VIDEO_CODEC },
- //{ QtMedia::PosterUrl, 0 },
+ //{ QtMultimedia::PosterUrl, 0 },
// Movie
- //{ QtMedia::ChapterNumber, 0 },
- //{ QtMedia::Director, 0 },
+ //{ QtMultimedia::ChapterNumber, 0 },
+ //{ QtMultimedia::Director, 0 },
{ QtMultimedia::LeadPerformer, GST_TAG_PERFORMER },
- //{ QtMedia::Writer, 0 },
+ //{ QtMultimedia::Writer, 0 },
// Photos
//{ QtMedia::CameraManufacturer, 0 },
//{ QtMedia::CameraModel, 0 },
//{ QtMedia::Event, 0 },
//{ QtMedia::Subject, 0 }
};
QGstreamerMetaDataProvider::QGstreamerMetaDataProvider(QGstreamerPlayerSession *session, QObject *parent)
@@ -54,70 +54,70 @@ struct QGstreamerMetaDataKeyLookup
#endif
- //{ QtMedia::Conductor, 0 },
- //{ QtMedia::Lyrics, 0 },
- //{ QtMedia::Mood, 0 },
+ //{ QtMultimedia::Conductor, 0 },
+ //{ QtMultimedia::Lyrics, 0 },
+ //{ QtMultimedia::Mood, 0 },
{ QtMultimedia::TrackNumber, GST_TAG_TRACK_NUMBER },
@@ -54,70 +54,70 @@ struct QGstreamerMetaDataKeyLookup
// Photos
- //{ QtMedia::CameraManufacturer, 0 },
- //{ QtMedia::CameraModel, 0 },
- //{ QtMedia::Event, 0 },
- //{ QtMedia::Subject, 0 }
+ //{ QtMultimedia::CameraManufacturer, 0 },
+ //{ QtMultimedia::CameraModel, 0 },
+ //{ QtMultimedia::Event, 0 },
+ //{ QtMultimedia::Subject, 0 }
};
QGstreamerMetaDataProvider::QGstreamerMetaDataProvider(QGstreamerPlayerSession *session, QObject *parent)